==> sharyn-11.4.0.tgz: package/shared/call.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _Object$defineProperty = require("@babel/runtime-corejs2/core-js/object/define-property");

_Object$defineProperty(exports, "__esModule", {
  value: true
});

exports["default"] = void 0;

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/objectSpread"));

var _axios = _interopRequireDefault(require("axios"));

var _spread = _interopRequireDefault(require("@sharyn/util/spread"));

var _spreadIf = _interopRequireDefault(require("@sharyn/util/spread-if"));

// flow-disable-next-line
// flow-disable-next-line
var call = function call(_ref) {
  var _authorizationBearer;

  var _ref$urlBase = _ref.urlBase,
      urlBase = _ref$urlBase === void 0 ? '' : _ref$urlBase,
      _ref$urlPath = _ref.urlPath,
      urlPath = _ref$urlPath === void 0 ? '/graphql' : _ref$urlPath,
      authorizationBearer = _ref.authorizationBearer,
      cookie = _ref.cookie,
      body = _ref.body,
      withCredentials = _ref.withCredentials;
  return _axios["default"].post("".concat(urlBase).concat(urlPath), body, (0, _objectSpread2["default"])({
    headers: (0, _objectSpread2["default"])({}, (0, _spreadIf["default"])(authorizationBearer, {
      Authorization: "Bearer ".concat((_authorizationBearer = authorizationBearer) !== null && _authorizationBearer !== void 0 ? _authorizationBearer : 'undefined')
    }), (0, _spread["default"])({
      cookie: cookie
    }))
  }, (0, _spread["default"])({
    withCredentials: withCredentials
  })));
};

var _default = call;
exports["default"] = _default;

==> sharyn-11.8.0.tgz: package/shared/call.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _Object$defineProperty = require("@babel/runtime-corejs2/core-js/object/define-property");

_Object$defineProperty(exports, "__esModule", {
  value: true
});

exports["default"] = void 0;

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/objectSpread"));

var _axios = _interopRequireDefault(require("axios"));

var _spread = _interopRequireDefault(require("@sharyn/util/spread"));

var _spreadIf = _interopRequireDefault(require("@sharyn/util/spread-if"));

// flow-disable-next-line
// flow-disable-next-line
var call = function call(_ref) {
  var _authorizationBearer;

  var _ref$urlBase = _ref.urlBase,
      urlBase = _ref$urlBase === void 0 ? '' : _ref$urlBase,
      _ref$urlPath = _ref.urlPath,
      urlPath = _ref$urlPath === void 0 ? '/graphql' : _ref$urlPath,
      authorizationBearer = _ref.authorizationBearer,
      cookie = _ref.cookie,
      body = _ref.body,
      withCredentials = _ref.withCredentials,
      cancelToken = _ref.cancelToken,
      _ref$axiosOptions = _ref.axiosOptions,
      axiosOptions = _ref$axiosOptions === void 0 ? {} : _ref$axiosOptions;
  return _axios["default"].post("".concat(urlBase).concat(urlPath), body, (0, _objectSpread2["default"])({
    headers: (0, _objectSpread2["default"])({}, (0, _spreadIf["default"])(authorizationBearer, {
      Authorization: "Bearer ".concat((_authorizationBearer = authorizationBearer) !== null && _authorizationBearer !== void 0 ? _authorizationBearer : 'undefined')
    }), (0, _spread["default"])({
      cookie: cookie
    }))
  }, axiosOptions, (0, _spread["default"])({
    withCredentials: withCredentials,
    cancelToken: cancelToken
  })));
};

var _default = call;
exports["default"] = _default;
